==> paperoni-0.1.3.tar.gz: paperoni-0.1.3/paperoni/utils.py <==
import shutil
import textwrap
import unicodedata
from collections import defaultdict

import requests
from blessed import Terminal
from hrepr import HTML
from tqdm import tqdm

H = HTML()
T = Terminal()
tw = shutil.get_terminal_size((80, 20)).columns


class PaperoniError(Exception):
    pass


def print_field(title, contents, bold=False):
    """Prints a line that goes 'title: contents', nicely formatted."""
    contents = "\n".join(textwrap.wrap(f"{title}: {contents}", width=tw))[
        len(title) + 2 :
    ]
    title = T.bold_cyan(f"{title}:")
    contents = T.bold(contents) if bold else contents
    print(title, contents)


def join(elems, sep=", ", lastsep=None):
    """Create a list using the given separators.

    If lastsep is None, lastsep = sep.

    Returns:
        [elem0, (sep, elem1), (sep, elem2), ... (lastsep, elemn)]
    """
    if lastsep is None:
        lastsep = sep
    elems = list(elems)
    if len(elems) <= 1:
        return elems
    results = [elems[0]]
    for elem in elems[1:-1]:
        results.extend((H.raw(sep), elem))
    results.extend((H.raw(lastsep), elems[-1]))
    return results


def download(url, filename):
    """Download the given url into the given filename."""
    print(f"Downloading {url}")
    r = requests.get(url, stream=True)
    total = int(r.headers.get("content-length") or "1024")
    with open(filename, "wb") as f:
        with tqdm(total=total) as progress:
            for chunk in r.iter_content(chunk_size=total // 100):
                f.write(chunk)
                f.flush()
                progress.update(len(chunk))
    print(f"Saved {filename}")


def asciiify(s):
    """Translate a string to pure ASCII, removing accents and the like.

    Non-ASCII characters that are not accented characters are removed.
    """
    norm = unicodedata.normalize("NFD", s)
    stripped = norm.encode("ASCII", "ignore")
    return stripped.decode("utf8")


def group_by(papers, key):
    """Group a sequence by the result of a key function."""
    groups = defaultdict(list)
    for p in papers:
        groups[key(p)].append(p)
    return groups


def normalize(s):
    if s is None:
        return None
    else:
        return asciiify(s).lower()

==> paperoni-0.1.7.tar.gz: paperoni-0.1.7/paperoni/utils.py <==
import shutil
import textwrap
import unicodedata
from collections import defaultdict

import requests
from blessed import Terminal
from hrepr import HTML
from tqdm import tqdm

H = HTML()
T = Terminal()
tw = shutil.get_terminal_size((80, 20)).columns


class PaperoniError(Exception):
    pass


def print_field(title, contents, bold=False):
    """Prints a line that goes 'title: contents', nicely formatted."""
    contents = textwrap.fill(f"{title}: {contents}", width=tw)[len(title) + 2 :]
    title = T.bold_cyan(f"{title}:")
    contents = T.bold(contents) if bold else contents
    print(title, contents)


def join(elems, sep=", ", lastsep=None):
    """Create a list using the given separators.

    If lastsep is None, lastsep = sep.

    Returns:
        [elem0, (sep, elem1), (sep, elem2), ... (lastsep, elemn)]
    """
    if lastsep is None:
        lastsep = sep
    elems = list(elems)
    if len(elems) <= 1:
        return elems
    results = [elems[0]]
    for elem in elems[1:-1]:
        results.extend((H.raw(sep), elem))
    results.extend((H.raw(lastsep), elems[-1]))
    return results


def download(url, filename):
    """Download the given url into the given filename."""
    print(f"Downloading {url}")
    r = requests.get(url, stream=True)
    total = int(r.headers.get("content-length") or "1024")
    with open(filename, "wb") as f:
        with tqdm(total=total) as progress:
            for chunk in r.iter_content(chunk_size=total // 100):
                f.write(chunk)
                f.flush()
                progress.update(len(chunk))
    print(f"Saved {filename}")


def asciiify(s):
    """Translate a string to pure ASCII, removing accents and the like.

    Non-ASCII characters that are not accented characters are removed.
    """
    norm = unicodedata.normalize("NFD", s)
    stripped = norm.encode("ASCII", "ignore")
    return stripped.decode("utf8")


def group_by(papers, key):
    """Group a sequence by the result of a key function."""
    groups = defaultdict(list)
    for p in papers:
        groups[key(p)].append(p)
    return groups


def normalize(s):
    if s is None:
        return None
    else:
        return asciiify(s).lower()
